@@ -15,7 +15,7 @@ You should have received a copy of the GNU Lesser General Public License
 along with this program.  If not, see <https://www.gnu.org/licenses/>.
 """
 
-__version__ = "0.4.0"
+__version__ = "0.6.0"
 
 import abc
 import contextlib
@@ -28,17 +28,28 @@ import uuid
 import warnings
 from enum import IntEnum
 from types import TracebackType
-from typing import Any, List, NoReturn, Optional, Tuple, TypeVar, Union
+from typing import (
+    Any,
+    List,
+    Literal,
+    NoReturn,
+    Optional,
+    Protocol,
+    Tuple,
+    Type,
+    TypeVar,
+    Union,
+    runtime_checkable,
+)
 
 import termcolor
-from typing_extensions import Literal, Protocol, Type, runtime_checkable
 
-try:
-    from types import UnionType
-except ImportError:
-    UnionType = type(Union[int, str])
+with contextlib.suppress(Exception):
+    import colorama
 
+    colorama.init()
 
+UnionType = type(Union[int, str])
 T = TypeVar("T")
 DEFAULT_FORMAT = "[{lvl} {time} line: {line}] {indent}{msg}"  # noqa: FS003
 
@@ -230,6 +241,14 @@ class SetAttr:
         """Exit the context manager."""
         setattr(self.obj, self.name, self.old_value)
 
+    def __repr__(self) -> str:  # pragma: no cover
+        return (
+            f"{self.__class__.__module__}.{self.__class__.__qualname__}"
+            f"(obj={self.obj!r},"
+            f" name={self.name!r},"
+            f" new_value={self.new_value!r})"
+        )
+
 
 @dataclasses.dataclass
 class LogEvent:
@@ -288,6 +307,9 @@ class NoHandler(Handler):
             event (LogEvent): The event.
         """
 
+    def __repr__(self) -> str:  # pragma: no cover
+        return f"{self.__class__.__module__}.{self.__class__.__qualname__}()"
+
 
 class StreamWriterHandler(Handler):
     """A handler to write to a stream."""
@@ -339,6 +361,15 @@ class StreamWriterHandler(Handler):
         if self.flush:
             self.stream.flush()
 
+    def __repr__(self) -> str:  # pragma: no cover
+        return (
+            f"{self.__class__.__module__}.{self.__class__.__qualname__}"
+            f"(stream={self.stream!r},"
+            f" flush={self.flush!r},"
+            f" use_colors={self.use_colors!r},"
+            f" format_msg={self.format_msg!r})"
+        )
+
 
 class Logger:
     """THE logger class. You shouldn't really call __init__; use the root\
@@ -363,6 +394,12 @@ class Logger:
             return self._id != __o._id
         return NotImplemented
 
+    def __repr__(self) -> str:  # pragma: no cover
+        return (
+            f"<Logger {self.__class__.__module__}."
+            f"{self.__class__.__qualname__} with id {self._id}>"
+        )
+
     def _inherit(self) -> None:
         # Made a separate function so it can be overwritten
 
@@ -620,7 +657,7 @@ class Logger:
             int: The number of characters written.
         """
         check_types(msg=(Stringable, msg), traceback=(bool, traceback))
-        return self._log(Level.debug, msg, traceback, 4)
+        return self._log(Level.debug, msg, traceback, 5)
 
     def info(
         self, msg: Stringable, traceback: bool = False
@@ -637,7 +674,7 @@ class Logger:
             int: The number of characters written.
         """
         check_types(msg=(Stringable, msg), traceback=(bool, traceback))
-        return self._log(Level.info, msg, traceback, 4)
+        return self._log(Level.info, msg, traceback, 5)
 
     def warning(
         self, msg: Stringable, traceback: bool = False
@@ -654,7 +691,7 @@ class Logger:
             int: The number of characters written.
         """
         check_types(msg=(Stringable, msg), traceback=(bool, traceback))
-        return self._log(Level.warning, msg, traceback, 4)
+        return self._log(Level.warning, msg, traceback, 5)
 
     def error(
         self, msg: Stringable, traceback: bool = False
@@ -671,7 +708,7 @@ class Logger:
             int: The number of characters written.
         """
         check_types(msg=(Stringable, msg), traceback=(bool, traceback))
-        return self._log(Level.error, msg, traceback, 4)
+        return self._log(Level.error, msg, traceback, 5)
 
     def critical(
         self, msg: Stringable, traceback: bool = False
@@ -688,7 +725,7 @@ class Logger:
             int: The number of characters written.
         """
         check_types(msg=(Stringable, msg), traceback=(bool, traceback))
-        return self._log(Level.critical, msg, traceback, 4)
+        return self._log(Level.critical, msg, traceback, 5)
 
     def get_child(self) -> "Logger":
         """
@@ -764,6 +801,12 @@ class IndentLogger:
         """
         self.logger.indent -= 1
 
+    def __repr__(self) -> str:  # pragma: no cover
+        return (
+            f"{self.__class__.__module__}.{self.__class__.__qualname__}"
+            f"(logger={self.logger!r})"
+        )
+
 
 class ChangeThreshold:
     """Change the threshold for a logger."""
@@ -807,6 +850,13 @@ class ChangeThreshold:
         """
         self.logger.threshold = self.old_level
 
+    def __repr__(self) -> str:  # pragma: no cover
+        return (
+            f"{self.__class__.__module__}.{self.__class__.__qualname__}"
+            f"(logger={self.logger!r},"
+            f" level={self.level!r})"
+        )
+
 
 _allow_root = True
 root = Logger()
